//**Start Encode**

function
TUpdateInstanceInfo(inSrc, inCompletionCallback, inCallingApp, inMinimalMessages)
{
	this.m_Instance = inSrc;
	this.m_NeedsCallback = inCompletionCallback;
	this.m_CallingApp = inCallingApp;
	this.m_MinimalMessages = inMinimalMessages;
}

function
THTTPInstanceInfo(inInstance, bInCompletionCallback, sInCallingApp)
{
	this.m_Instance = inInstance;
	this.m_NeedsCallback = bInCompletionCallback;
	this.m_CallingApp = sInCallingApp;
}

//========================================
function
TUpdateManager()
{
	// public
	this.NewUpdate = TUpdateManager_NewUpdate;
	
	this.StartUpdate = TUpdateManager_StartUpdate;
	this.CancelUpdate = TUpdateManager_CancelUpdate;
	
	this.PauseDownload = TUpdateManager_PauseDownload;
	this.CancelDownload = TUpdateManager_CancelDownload;
	this.ContinueDownload = TUpdateManager_ContinueDownload;
	this.CountActiveUpdates = TUpdateManager_CountActiveUpdates;
	this.CountActiveHTTPRequests = TUpdateManager_CountActiveHTTPRequests;
	
	this.CancelAllUpdates = TUpdateManager_CancelAllUpdates;
	
	
	this.NewHTTPPost = TUpdateManager_NewHTTPPost;
	
	// callback from update instance
	this.UpdateFinished = TUpdateManager_UpdateFinished;
	this.HTTPFinished = TUpdateManager_HTTPFinished;
	
	// private methods
	this.Initialize = TUpdateManager_Initialize;
	
	// properties
	this.m_UpdateInstanceArray = new RSSparseArray();
	this.m_HTTPInstanceArray = new RSSparseArray();
	this.m_UpdateInterface = null;
	this.m_NetworkInterface = null;
	
	// and initialize
	this.Initialize();
}
//========================================
function
TUpdateManager_Initialize()
{
	if(!this.m_UpdateInterface)
	{
		var updateAPI = window.external.Get_API("Gearbox.UpdateAPI.1");
		if(updateAPI )
		{
			this.m_UpdateInterface = updateAPI.Get_Interface("Gearbox.UpdateInterface.1");
			
			top.DEBUGLOG("UPD_MESSAGE: ---- Initialized r2 Updater----");
		}
	}
	
	try
	{
		if(!this.m_NetworkInterface)
		{
			var networkAPI = window.external.Get_API("Gearbox.NetworkingAPI.1");
			if(networkAPI )
			{
				this.m_NetworkInterface = networkAPI.Get_Interface("Gearbox.NetworkingInterface.1");
			}
		}
	}
	catch(e)
	{
	}
}
//========================================
//NOTE: why teh return value?...it returns true ONLY IF a new instance was created
function
TUpdateManager_NewUpdate(updateSource, wantsCompletion, callingApp, minimalMessages)
{
	var retValue = false;

	try
	{
		if(this.m_UpdateInstanceArray[updateSource]){
			return false;
		}
	
		// create a callback
		var callback = new TUpdateInstanceCallback(updateSource);
		
		// create the instance
		var instance = this.m_UpdateInterface.New_Update(updateSource, callback);
		
		// create the instance info for storage
		var uiInfo = new TUpdateInstanceInfo(instance, wantsCompletion, callingApp, minimalMessages);
		
		// add the instance to the array
		this.m_UpdateInstanceArray[updateSource] = uiInfo;
		
		// set the return value
		retValue = true; 
		
		top.DEBUGLOG("UPD_MESSAGE: New update=" + updateSource + "," + callingApp);
	}
	catch(e)
	{
	
	}
	
	return retValue;
}
//========================================
function
TUpdateManager_StartUpdate(inSrc, inParams, inUsePost)
{
	var retValue = false;
	
	try
	{
		// find the update
		var instance = this.m_UpdateInstanceArray[inSrc].m_Instance;
		if(instance)
		{

			//LAM - deal with post params
			retValue = instance.Process_Update(inParams);
			
			top.DEBUGLOG("UPD_MESSAGE: Update Started=" + inSrc + ", PARAMS=" + inParams);
		}
	}
	catch(e)
	{
		top.DEBUGLOG("UPD_MESSAGE: Err in start update -->" + e.description);
	}
	
	return retValue;
}
//========================================
function
TUpdateManager_UpdateFinished(inSrc, inSuccess, messageStore, updateCancelled)
{
	try
	{

		var item = this.m_UpdateInstanceArray[inSrc];
		
		// sanity check
		if(!item){
			top.DEBUGLOG("UPD_MESSAGE: WARNING! Update finished=" + inSrc + "NO update instance in queue!");
			return;
		}

		//Process update messages...
		if (messageStore)
		{
			var strConcatenatedMessages = "";
			var i;
			for(i=0; i<messageStore.length; i++)
			{
				if (i>0)
					strConcatenatedMessages += "\n\n";	
				strConcatenatedMessages += messageStore[i];
			}
			
			if (strConcatenatedMessages.length)
				HandleUpdateMessage(strConcatenatedMessages);
		}
		
		// sanity check for no item...
		//NOTE: boc - I don't know why this 
		
		// see if this needs a callback
		var wantsCallback = item.m_NeedsCallback;
		var callingApp = item.m_CallingApp;
		
		top.DEBUGLOG("UPD_MESSAGE: Update finished=" + inSrc);

		//boc - R4 - notify the user that update is complete
		
		//PJK 01.07.05 - R6: Display the final message whether we succeed or not but only IF the update was cancelled, i.e. a prompt was rejected OR
		//if minimal messages is turned off, i.e. when an update is invoked from the menu item (in which case the user should be given a failure message)
		if (/*inSuccess || */updateCancelled || !item.m_MinimalMessages)
		{
			if (!inSuccess)
			{
				var finalMessage = updateCancelled ? kUStr_UpdateCompletedWithErrors : kUStr_UpdateCompletedNoUpdates;
				HandleUpdateMessage(finalMessage);
			}
		}
		
		delete(this.m_UpdateInstanceArray[inSrc]);

		// if needs a callback, send the message
		if(wantsCallback)
		{
			var msgSuccess = (inSuccess ? "true" : "false");
			var msg = inSrc + "|" + msgSuccess;
			SendControllerMessage(callingApp, "eMsg_UpdateCompleted", msg);
		}
		
		setTimeout("CheckCloseStatus();", 1000); 
	}
	catch(e)
	{
		top.DEBUGLOG("UPD_MESSAGE: Exception in update finished --> " + e.description);
	}

}

//========================================
function
TUpdateManager_CountActiveUpdates()
{
	var key;
	var count = 0;
	for(key in this.m_UpdateInstanceArray)
	{
		count++;
	}
	
	return count;
}

function
TUpdateManager_CancelAllUpdates()
{
	top.DEBUGLOG("UPD_MESSAGE: CancelAllUpdates");	
	for(key in this.m_UpdateInstanceArray)
	{
		top.DEBUGLOG("UPD_MESSAGE: Cancelling Update " + key);	
		try
		{
			var instance = this.m_UpdateInstanceArray[key];
			if (instance)
			{
				if (gPromptInProgress)
				{
					setTimeout("gUpdateMgr.CancelAllUpdates();", 5000);
					continue;
				}
							
				instance.m_Instance.Cancel_Update(false);
				//this.UpdateFinished(key, false, null, true);
			}
		}
		catch(e)
		{
			top.DEBUGLOG("UPD_MESSAGE: Error Cancelling Update " + e.description);
		}
	}
}

//========================================
function
TUpdateManager_CancelUpdate()
{
}
//========================================
function
TUpdateManager_PauseDownload()
{
	// unimplemented
}
//========================================
function
TUpdateManager_CancelDownload()
{
}
//========================================
function
TUpdateManager_ContinueDownload()
{
	// unimplemented
}

//------------------------------------------------------------
//
// HTTP Post
//
//------------------------------------------------------------
//========================================
function
TUpdateManager_HTTPFinished(inSrc, inCompletionMessage)
{
	var item = this.m_HTTPInstanceArray[inSrc];
	
	// see if this needs a callback
	var wantsCallback = item.m_NeedsCallback;
	var callingApp = item.m_CallingApp;
	
	delete(this.m_HTTPInstanceArray[inSrc]);
	
	top.DEBUGLOG("UPD_MESSAGE: http finished=" + inSrc);
	
	// if needs a callback, send the message
	if(wantsCallback)
	{
		var message = inSrc + "|" + inCompletionMessage;
		SendControllerMessage(callingApp, "eMsg_HTTPPostCompleted", message);
	}
}
//========================================
function
TUpdateManager_CountActiveHTTPRequests()
{
	var key;
	var count = 0;
	for(key in this.m_HTTPInstanceArray)
	{
		count++;
	}
	
	return count;
}
//========================================
function
TUpdateManager_NewHTTPPost(inSrc)
{
	var retValue = false;

	try
	{

		var httpRequest = new THTTPRequest(inSrc);
			httpRequest.m_URL = "http://www.rockstar.com";
			httpRequest.m_Post = false;
			httpRequest.m_File = "";
			httpRequest.m_Params = "";	
		
		// run the request
		var httpInstance = this.m_NetworkInterface.New_Http_Request(httpRequest);
		
		//var uiInfo = new TUpdateInstanceInfo(instance, wantsCompletion, callingApp);
		var uiInfo = new THTTPInstanceInfo(httpInstance, true, "bar");

		
		this.m_HTTPInstanceArray[inSrc] = uiInfo;
		
		// set the return value
		retValue = true; 
		
		//top.DEBUGLOG("UPD_MESSAGE: New http=" + updateSource + "," + callingApp);

	}
	catch(e)
	{
	
	}
	
	return retValue;
}
//========================================
function
THTTPRequest(inSrc)
{

	this.m_Window = window;
	this.m_URL = "";
	this.m_Post = false;//GET initially.
	this.m_File = ""; 
	this.m_Params = "";
	this.m_Cache = false;
	
	// custom
	this.m_Src = inSrc;

	this.Status = THTTPRequest_Status;
	this.Finished = THTTPRequest_Finished;
}
//========================================
function
THTTPRequest_Status(strMessageType, strStatus, nMessageCode, nProgress, nMaxProgress)
{
	HandleUpdateStatusText(strMessageType + "," + strStatus + "," + nMessageCode);
	
}
//========================================
function
THTTPRequest_Finished(strMessageType, strErrorMessage, nResultCode, strWindowsErrorMessage)
{
	gHTTPRequestSrc = this.m_Src;
	gHTTPRequestMessage = strMessageType;
	gHTTPRequestErrorMessage = strErrorMessage;
	gHTTPRequestResultCode = nResultCode;
	setTimeout("STATIC_HTTPRequest_Finished();", 500);
	
	
}
//========================================
var gHTTPRequestSrc = null;
var gHTTPRequestMessage = "";
var gHTTPRequestErrorMessage = "";
var gHTTPRequestResultCode = "";

function
STATIC_HTTPRequest_Finished()
{
	HandleUpdateStatusText(gHTTPRequestSrc + ": finished http request=" + gHTTPRequestMessage);
	//HandleUpdateStatusText(gHTTPInstance.Get_Data());

	gUpdateMgr.HTTPFinished(gHTTPRequestSrc, gHTTPRequestMessage);
}
